@@ -240,6 +240,7 @@ end
 
 function s040_aqua.OnUsableCancelUse(actor)
   Scenario.ResetGlobalTeleport(actor)
+  Scenario.CheckWarpToStart(actor)
 end
 
 function s040_aqua.OnUsableUse(actor)
@@ -257,10 +258,12 @@ end
 
 function s040_aqua.OnSubAreaChange(old_subarea, old_actorgroup, new_subarea, new_actorgroup, disable_fade)
   if old_subarea == "collision_camera_010" and new_subarea == "collision_camera_014" then
-    s040_aqua.LaunchCutscene_32()
+    --s040_aqua.LaunchCutscene_32()
   elseif old_subarea ~= "collision_camera_029" or new_subarea == "collision_camera_028" then     
       
   end
+
+  Scenario.UpdateProgressiveItemModels()
 end
 
 function s040_aqua.LaunchCutscene_32()
